@@ -115,11 +115,8 @@ class RemoteFileField(TextField):
         super(RemoteFileField, self).__init__(*args, **kwargs)
 
     def process_formdata(self, valuelist):
-        if valuelist:
-            self.data = valuelist[0]
-
-    def process_data(self, value):
-        TextField.__init__(self, value)
+        if self.data:
+            self.data.set_path(valuelist[0])
 
     def populate_obj(self, obj, name):
         if getattr(obj, name) is None:
@@ -152,7 +149,7 @@ class PictureField(TextField):
                 getattr(obj, name).set_path(self.raw_data[0])
 
     def process_formdata(self, valuelist):
-        if self.data:
+        if self.data:            
             self.data.set_path(valuelist[0])
 
 
